@@ -1,6 +1,7 @@
 ﻿define(['layoutManager', 'cardBuilder', 'datetime', 'mediaInfo', 'backdrop', 'listView', 'itemContextMenu', 'itemHelper', 'userdataButtons', 'dom', 'indicators', 'apphost', 'scrollStyles', 'emby-itemscontainer', 'emby-checkbox'], function (layoutManager, cardBuilder, datetime, mediaInfo, backdrop, listView, itemContextMenu, itemHelper, userdataButtons, dom, indicators, appHost) {
 
     var currentItem;
+    var currentRecordingFields;
 
     function getPromise(params) {
 
@@ -100,12 +101,9 @@
 
         var context = params.context;
 
-        LibraryMenu.setBackButtonVisible(true);
-        LibraryMenu.setMenuButtonVisible(false);
-
         LibraryBrowser.renderName(item, page.querySelector('.itemName'), false, context);
         LibraryBrowser.renderParentName(item, page.querySelector('.parentName'), context);
-        LibraryMenu.setTitle(item.SeriesName || item.Name);
+        LibraryMenu.setTitle('');
 
         Dashboard.getCurrentUser().then(function (user) {
 
@@ -175,25 +173,7 @@
                 hideAll(page, 'syncLocalContainer');
             }
 
-            if (item.Type == 'Program' && item.TimerId) {
-                hideAll(page, 'btnCancelRecording', true);
-            } else {
-                hideAll(page, 'btnCancelRecording');
-            }
-
-            if (item.Type == 'Program' && (!item.TimerId && !item.SeriesTimerId)) {
-
-                if (canPlay) {
-                    hideAll(page, 'btnRecord', true);
-                    hideAll(page, 'btnFloatingRecord');
-                } else {
-                    hideAll(page, 'btnRecord');
-                    hideAll(page, 'btnFloatingRecord', true);
-                }
-            } else {
-                hideAll(page, 'btnRecord');
-                hideAll(page, 'btnFloatingRecord');
-            }
+            showRecordingFields(page, item, user);
 
             var btnPlayExternalTrailer = page.querySelectorAll('.btnPlayExternalTrailer');
             for (var i = 0, length = btnPlayExternalTrailer.length; i < length; i++) {
@@ -227,12 +207,6 @@
                 }
             });
 
-            if (user.Policy.IsAdministrator) {
-                page.querySelector('.chapterSettingsButton').classList.remove('hide');
-            } else {
-                page.querySelector('.chapterSettingsButton').classList.add('hide');
-            }
-
             var itemBirthday = page.querySelector('#itemBirthday');
             if (item.Type == "Person" && item.PremiereDate) {
 
@@ -249,7 +223,7 @@
                 itemBirthday.classList.add('hide');
             }
 
-            var itemDeathDate = page.querySelector('#itemBirthday');
+            var itemDeathDate = page.querySelector('#itemDeathDate');
             if (item.Type == "Person" && item.EndDate) {
 
                 try {
@@ -317,6 +291,31 @@
         Dashboard.hideLoadingMsg();
     }
 
+    function showRecordingFields(page, item, user) {
+
+        if (currentRecordingFields) {
+            return;
+        }
+
+        var recordingFieldsElement = page.querySelector('.recordingFields');
+
+        if (item.Type == 'Program' && user.Policy.EnableLiveTvManagement) {
+
+            require(['recordingFields'], function (recordingFields) {
+
+                currentRecordingFields = new recordingFields({
+                    parent: recordingFieldsElement,
+                    programId: item.Id,
+                    serverId: item.ServerId
+                });
+                recordingFieldsElement.classList.remove('hide');
+            });
+        } else {
+            recordingFieldsElement.classList.add('hide');
+            recordingFieldsElement.innerHTML = '';
+        }
+    }
+
     function renderLinks(linksElem, item) {
 
         var links = [];
@@ -568,7 +567,8 @@
         var itemMiscInfo = page.querySelectorAll('.itemMiscInfo');
         for (i = 0, length = itemMiscInfo.length; i < length; i++) {
             mediaInfo.fillPrimaryMediaInfo(itemMiscInfo[i], item, {
-                interactive: true
+                interactive: true,
+                episodeTitle: false
             });
         }
         var itemGenres = page.querySelectorAll('.itemGenres');
@@ -899,7 +899,7 @@
 
         var options = {
             userId: Dashboard.getCurrentUserId(),
-            limit: 8,
+            limit: item.Type == "MusicAlbum" || item.Type == "MusicArtist" ? 8 : 10,
             fields: "PrimaryImageAspectRatio,UserData,CanDelete"
         };
 
@@ -920,7 +920,6 @@
             }
 
             similarCollapsible.classList.remove('hide');
-            similarCollapsible.querySelector('.similiarHeader').innerHTML = Globalize.translate('HeaderIfYouLikeCheckTheseOut', item.Name);
 
             var html = '';
 
@@ -943,7 +942,7 @@
             });
             html += '</div>';
 
-            var similarContent = page.querySelector('#similarContent');
+            var similarContent = similarCollapsible.querySelector('.similarContent');
             similarContent.innerHTML = html;
             ImageLoader.lazyChildren(similarContent);
         });
@@ -1113,7 +1112,8 @@
                     showIndexNumber: true,
                     playFromHere: true,
                     action: 'playallfromhere',
-                    lazy: true
+                    image: false,
+                    artist: false
                 });
                 isList = true;
             }
@@ -1142,7 +1142,7 @@
                     overlayText: true,
                     lazy: true,
                     showDetailsMenu: true,
-                    overlayPlayButton: AppInfo.enableAppLayouts,
+                    overlayPlayButton: true
                 });
             }
             else if (item.Type == "GameSystem") {
@@ -1406,13 +1406,13 @@
 
         var userDataIcons = page.querySelectorAll('.userDataIcons');
 
-        var html = userdataButtons.getIconsHtml({
-            item: item,
-            style: 'fab-mini'
-        });
-
         for (var i = 0, length = userDataIcons.length; i < length; i++) {
-            userDataIcons[i].innerHTML = html;
+
+            userdataButtons.fill({
+                item: item,
+                style: 'fab-mini',
+                element: userDataIcons[i]
+            });
         }
     }
 
@@ -1458,15 +1458,15 @@
             else if (review.Likes != null) {
 
                 if (review.Likes) {
-                    html += '<div style="background-color:transparent;background-image:url(\'css/images/fresh.png\');background-repeat:no-repeat;background-position:center center;background-size: cover;width:40px;height:40px;"></div>';
+                    html += '<div style="flex-shrink:0;background-color:transparent;background-image:url(\'css/images/fresh.png\');background-repeat:no-repeat;background-position:center center;background-size: cover;width:40px;height:40px;"></div>';
                 } else {
-                    html += '<div style="background-color:transparent;background-image:url(\'css/images/rotten.png\');background-repeat:no-repeat;background-position:center center;background-size: cover;width:40px;height:40px;"></div>';
+                    html += '<div style="flex-shrink:0;background-color:transparent;background-image:url(\'css/images/rotten.png\');background-repeat:no-repeat;background-position:center center;background-size: cover;width:40px;height:40px;"></div>';
                 }
             }
 
             html += '<div class="listItemBody two-line">';
 
-            html += '<div style="white-space:normal;">' + review.Caption + '</div>';
+            html += '<h3 class="listItemBodyText" style="white-space:normal;">' + review.Caption + '</h3>';
 
             var vals = [];
 
@@ -1477,7 +1477,7 @@
                 vals.push(review.Publisher);
             }
 
-            html += '<div class="secondary">' + vals.join(', ') + '.';
+            html += '<div class="secondary listItemBodyText">' + vals.join(', ') + '.';
             if (review.Date) {
 
                 try {
@@ -1494,7 +1494,7 @@
             html += '</div>';
 
             if (review.Url) {
-                html += '<div class="secondary"><a class="textlink" href="' + review.Url + '" target="_blank">' + Globalize.translate('ButtonFullReview') + '</a></div>';
+                html += '<div class="secondary listItemBodyText"><a class="textlink" href="' + review.Url + '" target="_blank">' + Globalize.translate('ButtonFullReview') + '</a></div>';
             }
 
             html += '</div>';
@@ -1639,10 +1639,13 @@
             });
         });
 
-        if (limitExceeded) {
-            page.querySelector('.moreScenes').classList.remove('hide');
-        } else {
-            page.querySelector('.moreScenes').classList.add('hide');
+        var moreScenesButton = page.querySelector('.moreScenes');
+        if (moreScenesButton) {
+            if (limitExceeded) {
+                moreScenesButton.classList.remove('hide');
+            } else {
+                moreScenesButton.classList.add('hide');
+            }
         }
     }
 
@@ -1810,73 +1813,14 @@
 
     function getVideosHtml(items, user, limit, moreButtonClass) {
 
-        var html = '';
-
-        for (var i = 0, length = items.length; i < length; i++) {
-
-            if (limit && i >= limit) {
-                break;
-            }
-
-            var item = items[i];
-
-            var cssClass = "card backdropCard scalableCard backdropCard-scalable";
-
-            var href = "itemdetails.html?id=" + item.Id;
-
-            var onclick = item.PlayAccess == 'Full' ? ' onclick="MediaController.play(\'' + item.Id + '\'); return false;"' : "";
-
-            html += '<a class="' + cssClass + '" href="' + href + '"' + onclick + '>';
-
-            html += '<div class="cardBox">';
-            html += '<div class="cardScalable">';
-
-            var imageTags = item.ImageTags || {};
-
-            var imgUrl;
-
-            if (imageTags.Primary) {
-
-                imgUrl = ApiClient.getScaledImageUrl(item.Id, {
-                    maxWidth: 400,
-                    tag: imageTags.Primary,
-                    type: "primary"
-                });
-
-            } else {
-                imgUrl = "css/images/items/detail/video.png";
-            }
-
-            html += '<div class="cardPadder cardPadder-backdrop"></div>';
-
-            html += '<div class="cardContent">';
-            html += '<div class="cardImage lazy" data-src="' + imgUrl + '"></div>';
-
-            html += '<div class="innerCardFooter">';
-            html += '<div class="cardText">' + item.Name + '</div>';
-            html += '<div class="cardText">';
-            if (item.RunTimeTicks != "") {
-                html += datetime.getDisplayRunningTime(item.RunTimeTicks);
-            }
-            else {
-                html += "&nbsp;";
-            }
-            html += '</div>';
-
-            //cardFooter
-            html += "</div>";
-
-            // cardContent
-            html += '</div>';
-
-            // cardScalable
-            html += '</div>';
-
-            // cardBox
-            html += '</div>';
-
-            html += '</a>';
-        }
+        var html = cardBuilder.getCardsHtml({
+            items: items,
+            shape: "auto",
+            showTitle: true,
+            action: 'play',
+            overlayText: true,
+            showRuntime: true
+        });
 
         if (limit && items.length > limit) {
             html += '<p style="margin: 0;padding-left:5px;"><button is="emby-button" type="button" class="raised more ' + moreButtonClass + '">' + Globalize.translate('ButtonMore') + '</button></p>';
@@ -1926,10 +1870,13 @@
             });
         });
 
-        if (limitExceeded && !enableScrollX()) {
-            page.querySelector('.morePeople').classList.remove('hide');
-        } else {
-            page.querySelector('.morePeople').classList.add('hide');
+        var morePeopleButton = page.querySelector('.morePeople');
+        if (morePeopleButton) {
+            if (limitExceeded && !enableScrollX()) {
+                morePeopleButton.classList.remove('hide');
+            } else {
+                morePeopleButton.classList.add('hide');
+            }
         }
     }
 
@@ -2136,16 +2083,6 @@
             elems[i].addEventListener('change', onSyncLocalClick);
         }
 
-        elems = view.querySelectorAll('.btnRecord,.btnFloatingRecord');
-        for (i = 0, length = elems.length; i < length; i++) {
-            elems[i].addEventListener('click', onRecordClick);
-        }
-
-        elems = view.querySelectorAll('.btnCancelRecording');
-        for (i = 0, length = elems.length; i < length; i++) {
-            elems[i].addEventListener('click', onCancelRecordingClick);
-        }
-
         elems = view.querySelectorAll('.btnMoreCommands');
         for (i = 0, length = elems.length; i < length; i++) {
             elems[i].addEventListener('click', onMoreCommandsClick);
@@ -2179,9 +2116,14 @@
         function editImages() {
             return new Promise(function (resolve, reject) {
 
-                require(['components/imageeditor/imageeditor'], function (ImageEditor) {
+                require(['imageEditor'], function (imageEditor) {
 
-                    ImageEditor.show(currentItem.Id).then(resolve, reject);
+                    imageEditor.show({
+
+                        itemId: currentItem.Id,
+                        serverId: currentItem.ServerId
+
+                    }).then(resolve, reject);
                 });
             });
         }
@@ -2224,10 +2166,6 @@
 
         }
 
-        view.querySelector('.chapterSettingsButton').addEventListener('click', function () {
-            Dashboard.navigate('librarysettings.html');
-        });
-
         view.addEventListener('viewbeforeshow', function () {
             var page = this;
             reload(page, params);
@@ -2238,6 +2176,7 @@
         view.addEventListener('viewbeforehide', function () {
 
             currentItem = null;
+            currentRecordingFields = null;
 
             Events.off(ApiClient, 'websocketmessage', onWebSocketMessage);
             LibraryMenu.setTransparentMenu(false);
