@@ -1,4 +1,4 @@
-﻿define(['components/categorysyncbuttons', 'cardBuilder', 'scripts/livetvcomponents', 'emby-button', 'listViewStyle', 'emby-itemscontainer'], function (categorysyncbuttons, cardBuilder) {
+﻿define(['components/categorysyncbuttons', 'cardBuilder', 'apphost', 'scripts/livetvcomponents', 'emby-button', 'listViewStyle', 'emby-itemscontainer'], function (categorysyncbuttons, cardBuilder, appHost) {
 
     function getRecordingGroupHtml(group) {
 
@@ -76,6 +76,9 @@
             recordingItems.classList.add('vertical-wrap');
         }
 
+        var supportsImageAnalysis = appHost.supports('imageanalysis');
+        var cardLayout = appHost.preferVisualCards || supportsImageAnalysis;
+
         recordingItems.innerHTML = cardBuilder.getCardsHtml(Object.assign({
             items: recordings,
             shape: (enableScrollX() ? 'autooverflow' : 'auto'),
@@ -83,43 +86,49 @@
             showParentTitle: true,
             coverImage: true,
             lazy: true,
-            cardLayout: true,
-            allowBottomPadding: !enableScrollX()
+            cardLayout: cardLayout,
+            centerText: !cardLayout,
+            vibrant: supportsImageAnalysis,
+            allowBottomPadding: !enableScrollX(),
+            preferThumb: 'auto'
+
         }, cardOptions || {}));
 
         ImageLoader.lazyChildren(recordingItems);
     }
 
-    function renderActiveRecordings(context) {
+    function getBackdropShape() {
+        return enableScrollX() ? 'overflowBackdrop' : 'backdrop';
+    }
 
-        ApiClient.getLiveTvTimers({
+    function renderActiveRecordings(context, promise) {
 
-            IsActive: true
-
-        }).then(function (result) {
+        promise.then(function (result) {
 
             // The IsActive param is new, so handle older servers that don't support it
             if (result.Items.length && result.Items[0].Status != 'InProgress') {
                 result.Items = [];
             }
 
-            renderTimers(context.querySelector('#activeRecordings'), result.Items, {
-                indexByDate: false
+            renderRecordings(context.querySelector('#activeRecordings'), result.Items, {
+                shape: getBackdropShape(),
+                showParentTitle: false,
+                showTitle: true,
+                showAirTime: true,
+                showAirEndTime: true,
+                showChannelName: true,
+                cardLayout: true,
+                vibrant: true,
+                preferThumb: true,
+                coverImage: true,
+                overlayText: false
             });
         });
     }
 
-    function renderLatestRecordings(context) {
+    function renderLatestRecordings(context, promise) {
 
-        ApiClient.getLiveTvRecordings({
-
-            UserId: Dashboard.getCurrentUserId(),
-            Limit: enableScrollX() ? 12 : 8,
-            IsInProgress: false,
-            Fields: 'CanDelete,PrimaryImageAspectRatio,BasicSyncInfo',
-            EnableTotalRecordCount: false
-
-        }).then(function (result) {
+        promise.then(function (result) {
 
             renderRecordings(context.querySelector('#latestRecordings'), result.Items);
 
@@ -127,18 +136,9 @@
         });
     }
 
-    function renderMovieRecordings(context) {
+    function renderMovieRecordings(context, promise) {
 
-        ApiClient.getLiveTvRecordings({
-
-            UserId: Dashboard.getCurrentUserId(),
-            Limit: enableScrollX() ? 12 : 8,
-            IsInProgress: false,
-            Fields: 'CanDelete,PrimaryImageAspectRatio,BasicSyncInfo',
-            EnableTotalRecordCount: false,
-            IsMovie: true
-
-        }).then(function (result) {
+        promise.then(function (result) {
 
             renderRecordings(context.querySelector('#movieRecordings'), result.Items, {
                 showYear: true,
@@ -147,18 +147,9 @@
         });
     }
 
-    function renderEpisodeRecordings(context) {
+    function renderEpisodeRecordings(context, promise) {
 
-        ApiClient.getLiveTvRecordingSeries({
-
-            UserId: Dashboard.getCurrentUserId(),
-            Limit: enableScrollX() ? 12 : 8,
-            IsInProgress: false,
-            Fields: 'CanDelete,PrimaryImageAspectRatio,BasicSyncInfo',
-            EnableTotalRecordCount: false,
-            IsSeries: true
-
-        }).then(function (result) {
+        promise.then(function (result) {
 
             renderRecordings(context.querySelector('#episodeRecordings'), result.Items, {
                 showItemCounts: true,
@@ -167,18 +158,9 @@
         });
     }
 
-    function renderSportsRecordings(context) {
+    function renderSportsRecordings(context, promise) {
 
-        ApiClient.getLiveTvRecordings({
-
-            UserId: Dashboard.getCurrentUserId(),
-            Limit: enableScrollX() ? 12 : 8,
-            IsInProgress: false,
-            Fields: 'CanDelete,PrimaryImageAspectRatio,BasicSyncInfo',
-            EnableTotalRecordCount: false,
-            IsSports: true
-
-        }).then(function (result) {
+        promise.then(function (result) {
 
             renderRecordings(context.querySelector('#sportsRecordings'), result.Items, {
                 showYear: true,
@@ -187,18 +169,9 @@
         });
     }
 
-    function renderKidsRecordings(context) {
+    function renderKidsRecordings(context, promise) {
 
-        ApiClient.getLiveTvRecordings({
-
-            UserId: Dashboard.getCurrentUserId(),
-            Limit: enableScrollX() ? 12 : 8,
-            IsInProgress: false,
-            Fields: 'CanDelete,PrimaryImageAspectRatio,BasicSyncInfo',
-            EnableTotalRecordCount: false,
-            IsKids: true
-
-        }).then(function (result) {
+        promise.then(function (result) {
 
             renderRecordings(context.querySelector('#kidsRecordings'), result.Items, {
                 showYear: true,
@@ -207,50 +180,11 @@
         });
     }
 
-    function renderTimers(context, timers, options) {
-
-        LiveTvHelpers.getTimersHtml(timers, options).then(function (html) {
-
-            var elem = context;
-
-            if (html) {
-                elem.classList.remove('hide');
-            } else {
-                elem.classList.add('hide');
-            }
-
-            elem.querySelector('.recordingItems').innerHTML = html;
-
-            ImageLoader.lazyChildren(elem);
-        });
-    }
-
-    function reload(context) {
-
-        Dashboard.showLoadingMsg();
-
-        renderActiveRecordings(context);
-        renderLatestRecordings(context);
-        renderMovieRecordings(context);
-        renderEpisodeRecordings(context);
-        renderSportsRecordings(context);
-        renderKidsRecordings(context);
-
-        ApiClient.getLiveTvRecordingGroups({
-
-            userId: Dashboard.getCurrentUserId()
-
-        }).then(function (result) {
-
-            renderRecordingGroups(context, result.Items);
-        });
-    }
-
     function onMoreClick(e) {
 
         var type = this.getAttribute('data-type');
 
-        switch(type) {
+        switch (type) {
             case 'latest':
                 Dashboard.navigate('livetvitems.html?type=Recordings');
                 break;
@@ -277,6 +211,12 @@
     return function (view, params, tabContent) {
 
         var self = this;
+        var activeRecordingsPromise;
+        var sportsPromise;
+        var kidsPromise;
+        var moviesPromise;
+        var seriesPromise;
+        var latestPromise;
 
         categorysyncbuttons.init(tabContent);
 
@@ -286,11 +226,89 @@
         }
 
         tabContent.querySelector('#activeRecordings .recordingItems').addEventListener('timercancelled', function () {
-            reload(tabContent);
+            self.preRender();
+            self.renderTab();
         });
 
+        self.preRender = function () {
+
+            activeRecordingsPromise = ApiClient.getLiveTvRecordings({
+
+                UserId: Dashboard.getCurrentUserId(),
+                IsInProgress: true,
+                Fields: 'CanDelete,PrimaryImageAspectRatio,BasicSyncInfo',
+                EnableTotalRecordCount: false,
+                EnableImageTypes: "Primary,Thumb,Backdrop"
+            });
+
+            latestPromise = ApiClient.getLiveTvRecordings({
+
+                UserId: Dashboard.getCurrentUserId(),
+                Limit: enableScrollX() ? 12 : 8,
+                IsInProgress: false,
+                Fields: 'CanDelete,PrimaryImageAspectRatio,BasicSyncInfo',
+                EnableTotalRecordCount: false,
+                EnableImageTypes: "Primary,Thumb,Backdrop"
+            });
+
+            moviesPromise = ApiClient.getLiveTvRecordings({
+
+                UserId: Dashboard.getCurrentUserId(),
+                Limit: enableScrollX() ? 12 : 8,
+                IsInProgress: false,
+                Fields: 'CanDelete,PrimaryImageAspectRatio,BasicSyncInfo',
+                EnableTotalRecordCount: false,
+                IsMovie: true
+            });
+
+            seriesPromise = ApiClient.getLiveTvRecordingSeries({
+
+                UserId: Dashboard.getCurrentUserId(),
+                Limit: enableScrollX() ? 12 : 8,
+                IsInProgress: false,
+                Fields: 'CanDelete,PrimaryImageAspectRatio,BasicSyncInfo',
+                EnableTotalRecordCount: false,
+                IsSeries: true
+            });
+
+            kidsPromise = ApiClient.getLiveTvRecordings({
+
+                UserId: Dashboard.getCurrentUserId(),
+                Limit: enableScrollX() ? 12 : 8,
+                IsInProgress: false,
+                Fields: 'CanDelete,PrimaryImageAspectRatio,BasicSyncInfo',
+                EnableTotalRecordCount: false,
+                IsKids: true
+            });
+
+            sportsPromise = ApiClient.getLiveTvRecordings({
+                UserId: Dashboard.getCurrentUserId(),
+                Limit: enableScrollX() ? 12 : 8,
+                IsInProgress: false,
+                Fields: 'CanDelete,PrimaryImageAspectRatio,BasicSyncInfo',
+                EnableTotalRecordCount: false,
+                IsSports: true
+            });
+        };
+
         self.renderTab = function () {
-            reload(tabContent);
+            Dashboard.showLoadingMsg();
+
+            renderActiveRecordings(tabContent, activeRecordingsPromise);
+            renderLatestRecordings(tabContent, latestPromise);
+            renderMovieRecordings(tabContent, moviesPromise);
+            renderEpisodeRecordings(tabContent, seriesPromise);
+            renderSportsRecordings(tabContent, sportsPromise);
+            renderKidsRecordings(tabContent, kidsPromise);
+
+            ApiClient.getLiveTvRecordingGroups({
+
+                userId: Dashboard.getCurrentUserId()
+
+            }).then(function (result) {
+
+                renderRecordingGroups(tabContent, result.Items);
+            });
         };
     };
 
